@@ -545,7 +545,10 @@ class OpenEphysNPX(OpenEphysBase):
 
 		ap_sample_rate = 30000
 		n_channels = 384
-		trial_length = self.__calcTrialLengthFromBinarySize__(os.path.join(self.path2APdata, 'continuous.dat'), n_channels, ap_sample_rate)
+		trial_length = 0 # make sure a trial_length has a value
+		if self.path2APdata is not None:
+			if os.path.exists(os.path.join(self.path2APdata, 'continuous.dat')):
+				trial_length = self.__calcTrialLengthFromBinarySize__(os.path.join(self.path2APdata, 'continuous.dat'), n_channels, ap_sample_rate)
 		# Load the start time from the sync_messages file
 		if sync_message_file is not None:
 			with open(sync_message_file, 'r') as f:
@@ -557,6 +560,7 @@ class OpenEphysNPX(OpenEphysBase):
 					start_val = line[idx + len('start time: '):-1]
 					tmp = start_val.split('@')
 					recording_start_time = float(tmp[0]) / float(tmp[1][0:-1])
+			self.xyTS = self.xyTS - recording_start_time
 		else:
 			recording_start_time = self.xyTS[0]
 		self.recording_start_time = recording_start_time
@@ -625,6 +629,7 @@ class OpenEphysNPX(OpenEphysBase):
 					start_val = line[idx + len('start time: '):-1]
 					tmp = start_val.split('@')
 					recording_start_time = float(tmp[0]) / float(tmp[1][0:-1])
+			self.xyTS = self.xyTS - recording_start_time
 		else:
 			recording_start_time = self.xyTS[0]
 		self.recording_start_time = recording_start_time
